@@ -2,17 +2,8 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "Məktub",
-    "Inbox" : "Gələn qutusu",
-    "Sent" : "Göndərildi",
-    "Drafts" : "Qaralamalar",
-    "Archive" : "Arxiv",
-    "Trash" : "Zibil",
-    "Junk" : "Önəmsiz",
-    "All" : "Hamısı",
-    "Favorites" : "Sevimlilər",
     "Auto detect failed. Please use manual mode." : "Avtomatik təyinatda səhv baş verdi. Xahiş olunur əl rejimini seçəsiniz.",
     "Creating account failed: " : "Hesabın yaradılmasında səhv:",
-    "Delete permanently" : "Həmişəlik sil",
     "Connect" : "Qoşul",
     "Sending …" : "Göndərilir...",
     "Send" : "Göndər",
