@@ -32,7 +32,15 @@ OC.L10N.register(
     "Use Gravatar and favicon avatars" : "Fes servir avatars de Gravatar i favicon",
     "Keyboard shortcuts" : "Dreceres de teclat",
     "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Esteu cercant una manera de xifrar els vostres correus electrònics? Instal·leu l’extensió del navegador Mailvelope.",
+    "From" : "De",
+    "Select account" : "Selecciona un compte",
+    "To" : "A",
+    "+ Copy" : "+ Copia",
+    "Copy" : "Copia",
+    "No contacts found." : "No s'han trobat contactes.",
     "Subject" : "Assumpte",
+    "Subject …" : "Assumpte …",
+    "Write message …" : "Escriu missatge …",
     "Saving draft …" : "S'està desant l'esborrany ...",
     "Draft saved" : "S'ha desat l'esborrany",
     "Upload attachment" : "Carrega l'adjunt",
@@ -48,6 +56,7 @@ OC.L10N.register(
     "Send" : "Envia",
     "Uploading {percent}% …" : "S'està carregant {percent}% ...",
     "Choose a file to add as attachment" : "Trieu un fitxer per afegir als adjunts",
+    "Writing mode" : "Mode d'escriptura",
     "Plain text" : "Text net",
     "Rich text" : "Text enriquit",
     "No messages in this folder" : "No hi ha missatges en aquesta carpeta",
@@ -79,9 +88,15 @@ OC.L10N.register(
     "Collapse folders" : "Replega les carpetes",
     "Mark all as read" : "Marca-ho tot com a llegit",
     "Add subfolder" : "Afegeix una subcarpeta",
+    "{total} messages" : "{total} missatges",
+    "{unread} unread of {total}" : "{unread} no llegits de {total}",
+    "Loading …" : "Carregant …",
     "Could not load your draft" : "No s’ha pogut carregar el vostre esborrany",
+    "Could not load original message" : "No s'ha pogut carregar el missatge original",
     "No message selected" : "No s'ha seleccionat cap missatge",
     "Signature" : "Signatura",
+    "Account settings" : "Paràmetres del compte",
+    "Change name" : "Canvia el nom",
     "Mail server" : "Servidor de correu electrònic",
     "Speed up your Mail experience with these quick shortcuts." : "Accelereu l’experiència del correu electrònic amb aquestes dreceres ràpides.",
     "Compose new message" : "Crea un missatge nou",
