@@ -29,9 +29,20 @@ OC.L10N.register(
     "Connect" : "Σύνδεση",
     "Add mail account" : "Προσθήκη λογαριασμού αλληλογραφίας",
     "Keyboard shortcuts" : "Συντομεύσεις πληκτρολογίου",
+    "From" : "Από:",
+    "Select account" : "Επιλογή λογαριασμού",
+    "To" : "Προς",
+    "Contact or email address …" : "Επαφή ή διεύθυνση ηλ.ταχυδρομίου ...",
+    "+ Copy" : "+ Αντιγραφή",
+    "Copy" : "Αντιγραφή",
+    "No contacts found." : "Δεν βρέθηκαν επαφές",
     "Subject" : "Θέμα",
+    "Subject …" : "Θέμα...",
+    "Write message …" : "Εγγραφή μηνύματος ...",
     "Saving draft …" : "Αποθήκευση προχείρου ...",
     "Draft saved" : "Το πρόχειρο αποθηκεύτηκε",
+    "Upload attachment" : "Μεταφόρτωση συνημμένων",
+    "Add attachment from Files" : "Προσθήκη συνημμένου από Αρχεία",
     "Uploading attachments …" : "Ανέβασμα συνημμένων ...",
     "Sending …" : "Αποστέλλεται...",
     "Error sending your message" : "Σφάλμα κατά την αποστολή του μηνύματός σας",
@@ -41,12 +52,20 @@ OC.L10N.register(
     "Reply sent!" : "Η απάντηση στάλθηκε!",
     "Write another message" : "Γράψτε ένα άλλο μήνυμα",
     "Send" : "Αποστολή",
+    "Uploading {percent}% …" : "Μεταφόρτωση {percent}% …",
     "Choose a file to add as attachment" : "Επιλέξτε ένα αρχείο για να προσθέσετε ως συνημμένο",
+    "Plain text" : "Απλό κείμενο",
+    "Rich text" : "Εμπλουτισμένο κείμενο",
     "Draft: " : "Πρόχειρο:",
+    "Mark read" : "Σημείωση ως ανεγνωσμένου",
     "Mark unread" : "σημειώστε ως μη αναγνωσμένο",
     "Delete" : "Διαγραφή",
     "Report this bug" : "Αναφέρετε αυτό το σφάλμα",
+    "Loading messages" : "Φόρτωση μηνυμάτων",
     "Not found" : "Δε βρέθηκε",
+    "Reply" : "Απάντηση",
+    "Reply to sender only" : "Απάντηση μόνο στον αποστολέα",
+    "Forward" : "Προώθηση",
     "Import into calendar" : "Εισαγωγή στο ημερολόγιο",
     "Download attachment" : "Λήψη συνημμένου",
     "Save to Files" : "Αποθήκευση στα Αρχεία",
@@ -56,8 +75,29 @@ OC.L10N.register(
     "The images have been blocked to protect your privacy." : "Οι εικόνες έχουν αποκλειστεί για να προστατευθεί η ιδιωτικότητά σας.",
     "New message" : "Νέο μήνυμα",
     "Settings" : "Ρυθμίσεις",
+    "Edit account" : "Επεξεργασία λογαριασμού",
+    "Delete account" : "Διαγραφή λογαριασμού",
+    "Add folder" : "Προσθήκη φακέλου",
     "Show all folders" : "Εμφάνιση όλων των φακέλων",
     "Collapse folders" : "Σύμπτυξη φακέλων",
+    "Mark all messages of this folder as read" : "Σημείωση όλων των μυνημάτων ως αναγνωσμένων",
+    "Add subfolder" : "Προσθήκη υποφακέλου",
+    "{total} messages" : "{total} μυνήματα",
+    "Loading …" : "Φόρτωση…",
+    "Signature" : "Υπογραφή",
+    "Signature …" : "Υπογραφή...",
+    "Save signature" : "Αποθήκευση υπογραφής",
+    "Mail app" : "Εφαρμογή αλληλογραφίας",
+    "General" : "Γενικά",
+    "Email address" : "Διεύθυνση αλληλογραφίας",
+    "IMAP" : "IMAP",
+    "User" : "Χρήστης",
+    "Host" : "Διακομιστής",
+    "Port" : "Θύρα",
+    "SMTP" : "SMTP",
+    "Account settings" : "Ρυθμίσεις λογαριασμού",
+    "Change name" : "Αλλαγή ονόματος",
+    "Mail server" : "Διακομιστής αλληλογραφίας",
     "Speed up your Mail experience with these quick shortcuts." : "Βελτιώστε την ταχύτητά σας στην εμπειρία χρήσης στο πρόγραμμα Αλληλογραφίας με αυτές τις συντομεύσεις.",
     "Compose new message" : "Σύνταξη νέου μηνύματος",
     "Newer message" : "Νεότερο μήνυμα",
