@@ -38,6 +38,9 @@ OC.L10N.register(
     "Settings" : "Ezarpenak",
     "Show all folders" : "Erakutsi karpeta guztiak",
     "Collapse folders" : "Bildu karpetak",
+    "No message selected" : "Ez da mezurik hautatu",
+    "Signature" : "Sinadura",
+    "Mail server" : "Posta-zerbitzaria",
     "Speed up your Mail experience with these quick shortcuts." : "Zure Mail erabilpena azkartu lasterbide azkar hauekin",
     "Compose new message" : "Mezu berria idatzi",
     "Newer message" : "Mezu berriagoa",
