@@ -2,12 +2,7 @@ OC.L10N.register(
     "mail",
     {
     "Mail" : "ایمیل",
-    "Sent" : "ارسال شده",
-    "Archive" : "آرشیو",
-    "All" : "همه",
-    "Favorites" : "موارد محبوب",
     "Auto detect failed. Please use manual mode." : "شناسایی خودکار با شکست مواجه شد. لطفا از حالت دستی استفاده کنید.",
-    "Delete permanently" : "حذف قطعی",
     "Connect" : "اتصال",
     "Sending …" : "در حال ارسال ...",
     "Message sent!" : "پیام ارسال شد!",
