@@ -6,9 +6,11 @@ OC.L10N.register(
     "Updating account failed: " : "Paskyros atnaujinimas nepavyko: ",
     "Creating account failed: " : "Paskyros sukūrimas nepavyko: ",
     "💌 A mail app for Nextcloud" : "💌 Pašto programėlė, skirta Nextcloud",
+    "Auto" : "Automatiškai",
     "Name" : "Vardas",
     "Mail Address" : "Elektroninio pašto adresas",
     "Password" : "Slaptažodis",
+    "Manual" : "Rankiniu būdu",
     "IMAP Settings" : "IMAP nustatymai",
     "IMAP Host" : "IMAP serveris",
     "IMAP Security" : "IMAP saugumas",
@@ -31,7 +33,9 @@ OC.L10N.register(
     "Keyboard shortcuts" : "Klaviatūros greitieji klavišai",
     "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Ieškote būdo kaip šifruoti savo el. laiškus? Įsidiekite Mailvelope naršyklės plėtinį!",
     "Select account" : "Pasirinkti paskyrą",
+    "Contact or email address …" : "Adresatas ar el. pašto adresas…",
     "No contacts found." : "Adresatų nerasta.",
+    "Blind copy" : "Nematomoji kopija",
     "Subject" : "Tema",
     "Saving draft …" : "Įrašomas juodraštis …",
     "Draft saved" : "Juodraštis įrašytas",
@@ -86,6 +90,16 @@ OC.L10N.register(
     "Could not load your draft" : "Nepavyko įkelti jūsų juodraščio",
     "Signature" : "Parašas",
     "Save signature" : "Įrašyti parašą",
+    "Mail app" : "Pašto programėlė",
+    "The mail app allows users to read mails on their IMAP accounts." : "Pašto programėlė leidžia naudotojams skaityti laiškus savo IMAP paskyrose.",
+    "Email: {email}" : "El. paštas: {email}",
+    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} ties {host}:{port} ({ssl} šifravimas)",
+    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} ties {host}:{port} ({ssl} šifravimas)",
+    "Email address" : "El. pašto adresas",
+    "IMAP" : "IMAP",
+    "User" : "Naudotojas",
+    "Port" : "Prievadas",
+    "SMTP" : "SMTP",
     "Account settings" : "Paskyros nustatymai",
     "Mail server" : "Pašto serveris",
     "Speed up your Mail experience with these quick shortcuts." : "Padidinkite savo našumą naudodamiesi šiomis nuorodomis.",
