@@ -4,7 +4,7 @@ OC.L10N.register(
     "Mail" : "邮件",
     "Auto detect failed. Please use manual mode." : "自动检测失败，请使用手动模式。",
     "Updating account failed: " : "更新账号失败：",
-    "Creating account failed: " : "未能创建账号：",
+    "Creating account failed: " : "创建账号失败：",
     "💌 A mail app for Nextcloud" : "💌 Nextcloud 上的一款邮件应用",
     "**💌 A mail app for Nextcloud**\n\n- **🚀 Integration with other Nextcloud apps!** Currently Contacts, Calendar & Files – more to come.\n- **📥 Multiple mail accounts!** Personal and company account? No problem, and a nice unified inbox. Connect any IMAP account.\n- **🔒 Send & receive encrypted mails!** Using the great [Mailvelope](https://mailvelope.com) browser extension.\n- **🙈 We’re not reinventing the wheel!** Based on the great [Horde](http://horde.org) libraries.\n- **📬 Want to host your own mail server?** We don’t have to reimplement this as you could set up [Mail-in-a-Box](https://mailinabox.email)!" : "**💌 Nextcloud 上的一款邮件应用**\n\n- **🚀 与其他 Nextcloud 应用集成！** 当前已集成联系人、日历和文件应用 —— 后续还有更多。\n- **📥 多个邮箱账号！** 个人和公司账号？没问题，还有好用的统一收件箱。可连接任何 IMAP 账号。\n- **🔒 收发加密邮件！** 使用超棒的 [Mailvelope](https://mailvelope.com) 浏览器扩展。\n- **🙈 我们没有重复造轮子！** 基于超棒的 [Horde](http://horde.org) 软件库。\n- **📬 想托管您自己的邮件服务器？** 我们不需要重新实现这个功能，因为你们可以搭建 [Mail-in-a-Box](https://mailinabox.email)！",
     "Auto" : "自动",
@@ -29,7 +29,7 @@ OC.L10N.register(
     "SMTP Password" : "SMTP 密码",
     "Save" : "保存",
     "Connect" : "连接",
-    "Add mail account" : "添加邮件账户",
+    "Add mail account" : "添加邮件账号",
     "Use Gravatar and favicon avatars" : "使用 Gravatar 和 favicon 形象",
     "Keyboard shortcuts" : "键盘快捷方式",
     "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "在寻找加密您邮件的方法吗？安装 Mailvelope 浏览器扩展！",
@@ -106,6 +106,22 @@ OC.L10N.register(
     "A signature is added to the text of new messages and replies." : "签名已加入到 新消息 及 回复消息 的文本中。",
     "Signature …" : "签名...",
     "Save signature" : "保存签名",
+    "Mail app" : "邮件应用",
+    "The mail app allows users to read mails on their IMAP accounts." : "邮件应用允许用户阅读其 IMAP 账号中的邮件。",
+    "Email: {email}" : "电子邮件：{email}",
+    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} 在 {host}:{port} ({ssl} 加密)",
+    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} 在 {host}:{port} ({ssl} 加密)",
+    "Provision an account for every user" : "为每个用户设置一个账号",
+    "General" : "常规",
+    "Email address" : "Email 地址",
+    "IMAP" : "IMAP",
+    "User" : "用户",
+    "Host" : "主机",
+    "Port" : "端口",
+    "SMTP" : "SMTP",
+    "Apply and create/update for all users" : "为所有用户应用并 创建 / 更新",
+    "Disable and un-provision existing accounts" : "禁用和取消设置现有账号",
+    "With the settings above, the app will create account settings in the following way:" : "使用上述设置，该应用将通过以下方式创建账号设置：",
     "Account settings" : "账号设置",
     "Change name" : "更改名称",
     "Mail server" : "邮件服务器",
