@@ -49,10 +49,10 @@ interface IMailBox {
 
 	/**
 	 * @param int $messageId
-	 * @param int $attachmentId
+	 * @param string $attachmentId
 	 * @return Attachment
 	 */
-	public function getAttachment(int $messageId, int $attachmentId): Attachment;
+	public function getAttachment(int $messageId, string $attachmentId): Attachment;
 
 	/**
 	 * @param int $messageId
